@@ -12,7 +12,6 @@ from abc import ABC, abstractmethod, abstractproperty
 import math
 import pandas as pd
 import numpy as np
-from scipy.stats import sem
 from sklearn import set_config
 from sklearn.dummy import DummyClassifier, DummyRegressor
 
@@ -25,11 +24,13 @@ from ads.common.utils import (
     is_documentation_mode,
     is_notebook,
 )
+from ads.common.decorator.runtime_dependency import (
+    runtime_dependency,
+    OptionalDependency,
+)
 from ads.dataset.label_encoder import DataFrameLabelEncoder
 from ads.dataset.helper import is_text_data
 
-from IPython.core.display import display, HTML
-
 from ads.common import logger, utils
 
 
@@ -304,7 +305,9 @@ class BaselineAutoMLProvider(AutoMLProvider):
 
 # An installation of oracle labs automl is required only for this class
 class OracleAutoMLProvider(AutoMLProvider, ABC):
-    def __init__(self, n_jobs=-1, loglevel=None, logger_override=None):
+    def __init__(
+        self, n_jobs=-1, loglevel=None, logger_override=None, model_n_jobs: int = 1
+    ):
         """
         The Oracle AutoML Provider automatically provides a tuned ML pipeline that best models the given a training
         dataset and a prediction task at hand.
@@ -317,6 +320,9 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         loglevel : int
             The verbosity of output for Oracle AutoML. Can be specified using the Python logging module
             (https://docs.python.org/3/library/logging.html#logging-levels).
+        model_n_jobs: (optional, int). Defaults to 1.
+            Specifies the model parallelism used by AutoML.
+            This will be passed to the underlying model it is training.
         """
         try:
             self.automl = __import__("automl")
@@ -327,24 +333,13 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         super(OracleAutoMLProvider, self).__init__()
         if loglevel is None:
             loglevel = logging.DEBUG if ads.debug_mode else logging.ERROR
-        else:
-            loglevel = loglevel
-        if logger_override:
-            logr = logger_override
-        else:
-            logr = logging.getLogger(__name__)
-        if "AMD" in self.cpuinfo.get_cpu_info().get("brand", "UNKNOWN-BRAND"):
-            # Disable intra-model parallelism for LightGBM and XGBoost libraries
-            # which seem to be unstable currently on AMD shapes
-            self.automl.init(
-                engine="local",
-                engine_opts={"n_jobs": n_jobs, "model_n_jobs": 1},
-                loglevel=loglevel,
-            )
-        else:
-            self.automl.init(
-                engine="local", engine_opts={"n_jobs": n_jobs}, logger=logr
-            )
+
+        self.automl.init(
+            engine="local",
+            engine_opts={"n_jobs": n_jobs, "model_n_jobs": model_n_jobs},
+            logger=logger_override,
+            loglevel=loglevel,
+        )
 
     def __repr__(self):
         super(OracleAutoMLProvider, self).__repr__()
@@ -377,6 +372,7 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         """
         return self.est.selected_model_
 
+    @runtime_dependency(module="IPython", install_from=OptionalDependency.NOTEBOOK)
     def print_summary(
         self,
         max_rows=None,
@@ -469,6 +465,8 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
                 0, "Rank based on Performance", np.arange(2, len(sorted_summary_df) + 2)
             )
 
+            from IPython.core.display import display, HTML
+
             with pd.option_context(
                 "display.max_colwidth",
                 1000,
@@ -620,15 +618,16 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             )
             if not self.col_types:
                 if len(self.X_train.columns) == 1:
-                    self.col_types = ['text']
+                    self.col_types = ["text"]
                 elif len(self.X_train.columns) == 2:
-                    self.col_types = ['text', 'text']
+                    self.col_types = ["text", "text"]
                 else:
-                    raise ValueError("We detected a text classification problem. Pass " \
-                        "in `col_types = [<type of column1>, <type of column2>, ...]`." \
-                        " Valid types are: ['categorical', 'numerical', 'text', 'datetime'," \
+                    raise ValueError(
+                        "We detected a text classification problem. Pass "
+                        "in `col_types = [<type of column1>, <type of column2>, ...]`."
+                        " Valid types are: ['categorical', 'numerical', 'text', 'datetime',"
                         " 'timedelta']."
-                        )
+                    )
 
         elif self.ml_task_type == ml_task_types.REGRESSION:
             est = self.automl.Pipeline(
@@ -648,6 +647,7 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
             score_label = self.est.inferred_score_metric
         return score_label
 
+    @runtime_dependency(module="scipy", install_from=OptionalDependency.VIZ)
     def visualize_algorithm_selection_trials(self, ylabel=None):
         """
         Plot the scores predicted by Algorithm Selection for each algorithm. The
@@ -692,7 +692,7 @@ class OracleAutoMLProvider(AutoMLProvider, ABC):
         ax.set_ylabel(ylabel)
         ax.set_xlabel("Algorithm")
         for f in mean_scores_ser.keys():
-            se = sem(scores_ser[f], ddof=1)
+            se = scipy.stats.sem(scores_ser[f], ddof=1)
             y_error.append(se)
             if f == "{}_AS".format(self.est.selected_model_):
                 colors.append("orange")
