@@ -1,11 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import json
 import oci.ai_language
+import pandas as pd
 
 from ads.common import auth as authutil
 from ads.common import oci_client
@@ -17,7 +18,7 @@ class OCILanguage(object):  # pragma: no cover
         self.ai_client = oci_client.OCIClientFactory(**auth).ai_language
 
     @property
-    def ner(self):
+    def ner(self) -> pd.DataFrame:
         detect_language_entities_details = (
             oci.ai_language.models.DetectLanguageEntitiesDetails(text=self.string)
         )
@@ -27,7 +28,7 @@ class OCILanguage(object):  # pragma: no cover
         return json.loads(str(output.data))["entities"]
 
     @property
-    def lang(self):
+    def language_dominant(self) -> pd.DataFrame:
         detect_dominant_language_details = (
             oci.ai_language.models.DetectDominantLanguageDetails(text=self.string)
         )
@@ -37,7 +38,7 @@ class OCILanguage(object):  # pragma: no cover
         return json.loads(str(output.data))
 
     @property
-    def key_phrases(self):
+    def key_phrase(self) -> pd.DataFrame:
         detect_language_key_phrases_details = (
             oci.ai_language.models.DetectLanguageKeyPhrasesDetails(text=self.string)
         )
@@ -47,7 +48,7 @@ class OCILanguage(object):  # pragma: no cover
         return json.loads(str(output.data))["key_phrases"]
 
     @property
-    def sentiment(self):
+    def absa(self) -> pd.DataFrame:
         detect_language_sentiments_details = (
             oci.ai_language.models.DetectLanguageSentimentsDetails(text=self.string)
         )
@@ -57,7 +58,7 @@ class OCILanguage(object):  # pragma: no cover
         return json.loads(str(output.data))["aspects"]
 
     @property
-    def text_classification(self):
+    def text_classification(self) -> pd.DataFrame:
         detect_language_text_clf_details = (
             oci.ai_language.models.DetectLanguageTextClassificationDetails(
                 text=self.string
