@@ -1,21 +1,22 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*--
 
-# Copyright (c) 2021 Oracle and/or its affiliates.
+# Copyright (c) 2021, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import functools
+
 from typing import Any, Callable
-
 from ads.feature_engineering.feature_type.base import FeatureType
-
 from ads.feature_engineering.feature_type.adsstring.common_regex_mixin import (
     CommonRegexMixin,
 )
 from ads.feature_engineering.feature_type.adsstring.oci_language import OCILanguage
+from ads.common.decorator.runtime_dependency import OptionalDependency
+from ads.feature_engineering.feature_type.adsstring.oci_language import OCILanguage
 
 
-def to_ads_string(func: Callable) -> Callable:
+def to_adsstring(func: Callable) -> Callable:
     """Decorator that converts output of a function to `ADSString` if it returns a string.
 
     Parameters
@@ -61,20 +62,13 @@ def wrap_output_string(decorator: Callable) -> Callable:
                 and not attr.startswith("_")
                 and callable(getattr(cls, attr))
             ):
-                # temporary fix
-                if any(
-                    not a.startswith("__") and not a.startswith("_")
-                    for a in dir(getattr(cls, attr))
-                ):
-                    continue
-                else:
-                    setattr(cls, attr, decorator(getattr(cls, attr)))
+                setattr(cls, attr, decorator(getattr(cls, attr)))
         return cls
 
     return decorate
 
 
-@wrap_output_string(to_ads_string)
+@wrap_output_string(to_adsstring)
 class ADSString(str, FeatureType, CommonRegexMixin):
     """Defines an enhanced string class for the purporse of performing NLP tasks.
     Its functionalities can be extended by registering plugins.
@@ -88,7 +82,7 @@ class ADSString(str, FeatureType, CommonRegexMixin):
 
     Example
     -------
-    >>> ADSString.set_nlp_backend('nltk')
+    >>> ADSString.nlp_backend('nltk')
     >>> s = ADSString("Walking my dog on a breezy day is the best.")
     >>> s.lower() # regular string methods still work
     >>> s.replace("a", "e")
@@ -96,9 +90,9 @@ class ADSString(str, FeatureType, CommonRegexMixin):
     >>> s.parts_of_speech
     >>> s = ADSString("get in touch with my associate at john.smith@gmail.com to schedule")
     >>> s.emails
-    >>> ADSString.register_plugin(OCILanguage)
+    >>> ADSString.plugin_register(OCILanguage)
     >>> s = ADSString("This movie is awesome.")
-    >>> s.sentiment
+    >>> s.absa
     """
 
     plugins = []
@@ -155,7 +149,7 @@ class ADSString(str, FeatureType, CommonRegexMixin):
         return self._string
 
     @classmethod
-    def set_nlp_backend(cls, backend: str = "nltk") -> None:
+    def nlp_backend(cls, backend: str = "nltk") -> None:
         """Set backend for extracting NLP related properties.
 
         Parameters
@@ -178,12 +172,15 @@ class ADSString(str, FeatureType, CommonRegexMixin):
             try:
                 import spacy
             except:
-                raise ModuleNotFoundError("spacy must be installed.")
+                raise ModuleNotFoundError(
+                    f"The `spacy` module was not found. Please run "
+                    f"`pip install {OptionalDependency.TEXT}`."
+                )
             from ads.feature_engineering.feature_type.adsstring.parsers.spacy_parser import (
                 SpacyParser,
             )
 
-            cls.register_plugin(SpacyParser)
+            cls.plugin_register(SpacyParser)
         elif backend == "nltk":
             try:
                 import nltk
@@ -193,19 +190,19 @@ class ADSString(str, FeatureType, CommonRegexMixin):
                 NLTKParser,
             )
 
-            cls.register_plugin(NLTKParser)
+            cls.plugin_register(NLTKParser)
         else:
             raise ValueError(
                 "Currently only `nltk` and `spacy` are supported. Default uses `nltk`."
             )
 
     @classmethod
-    def clear_plugins(cls) -> None:
+    def plugin_clear(cls) -> None:
         """Clears plugins."""
         cls.plugins.clear()
 
     @classmethod
-    def register_plugin(cls, plugin: Any) -> None:
+    def plugin_register(cls, plugin: Any) -> None:
         """Register a plugin
 
         Parameters
@@ -220,11 +217,42 @@ class ADSString(str, FeatureType, CommonRegexMixin):
         cls.plugins.append(plugin)
 
     @classmethod
-    def help(cls) -> None:
-        """List available properties."""
-        props = [
-            attr
-            for attr in dir(cls)
-            if not attr.startswith("__") and not attr.startswith("_")
-        ]
-        print(f"{cls.__name__}::Available properties: {', '.join(props)}")
+    def plugin_list(cls) -> None:
+        """List registered plugins."""
+        if not cls.plugins:
+            print("No plugin registered.")
+            return []
+
+        return [plugin.__name__ for plugin in cls.plugins]
+
+    @classmethod
+    def help(cls, plugin: Any = None) -> None:
+        """List available properties.
+
+        Parameters
+        ----------
+        plugin : Any
+            registered plugin
+
+        Returns
+        -------
+        None
+        """
+        if not plugin:
+            props = [
+                attr
+                for attr in dir(cls)
+                if not attr.startswith("__") and not attr.startswith("_")
+            ]
+            print(f"{cls.__name__}::Available properties: {', '.join(props)}")
+
+        else:
+            props = [
+                attr
+                for attr in dir(plugin)
+                if not attr.startswith("__") and not attr.startswith("_")
+            ]
+            print(
+                f"{cls.__name__}::Available properties from plugin, {plugin.__name__}:"
+            )
+            print(props)
