@@ -15,6 +15,7 @@ import oci.loggingsearch
 import pandas as pd
 import requests
 from ads.common.auth import default_signer
+from ads.common.data_serializer import InputDataSerializer
 from ads.common.oci_client import OCIClientFactory
 from ads.common.oci_logging import LOG_INTERVAL, LOG_RECORDS_LIMIT, OCILog
 
@@ -26,8 +27,6 @@ DEFAULT_WAIT_TIME = 1200
 DEFAULT_POLL_INTERVAL = 30
 DEFAULT_WORKFLOW_STEPS = 6
 DEFAULT_RETRYING_REQUEST_ATTEMPTS = 3
-DEFAULT_CONTENT_TYPE_JSON = "application/json"
-DEFAULT_CONTENT_TYPE_BYTES = "application/octet-stream"
 TERMINAL_STATES = [State.ACTIVE, State.FAILED, State.DELETED, State.INACTIVE]
 
 
@@ -152,7 +151,7 @@ class ModelDeployment:
     ----------
     config: (dict)
         Deployment configuration parameters
-    deployment_properties: (ModelDeploymentProperties)
+    properties: (ModelDeploymentProperties)
         ModelDeploymentProperties object
     workflow_state_progress: (str)
         Workflow request id
@@ -185,32 +184,32 @@ class ModelDeployment:
 
     def __init__(
         self,
-        properties=None,
-        config=None,
-        workflow_req_id=None,
-        model_deployment_id=None,
-        model_deployment_url="",
+        properties: Union[ModelDeploymentProperties, Dict] = None,
+        config: Dict = None,
+        workflow_req_id: str = None,
+        model_deployment_id: str = None,
+        model_deployment_url: str = "",
         **kwargs,
     ):
-        """Initializes a ModelDeployment
+        """Initializes a ModelDeployment object.
 
         Parameters
         ----------
-        properties: ModelDeploymentProperties or dict
+        properties: (Union[ModelDeploymentProperties, Dict], optional). Defaults to None.
             Object containing deployment properties.
-            properties can be None when kwargs are used for specifying properties.
-        config: dict
+            The properties can be `None` when `kwargs` are used for specifying properties.
+        config: (Dict, optional). Defaults to None.
             ADS auth dictionary for OCI authentication.
-            This can be generated by calling ads.common.auth.api_keys() or ads.common.auth.resource_principal().
-            If this is None, ads.common.default_signer(client_kwargs) will be used.
-        workflow_req_id: str
-            Workflow request id. Defaults to ""
-        model_deployment_id: str
-            Model deployment OCID. Defaults to ""
-        model_deployment_url: str
-            Model deployment url. Defaults to ""
+            This can be generated by calling `ads.common.auth.api_keys()` or `ads.common.auth.resource_principal()`.
+            If this is `None` then the `ads.common.default_signer(client_kwargs)` will be used.
+        workflow_req_id: (str, optional). Defaults to None.
+            Workflow request id.
+        model_deployment_id: (str, optional). Defaults to None.
+            Model deployment OCID.
+        model_deployment_url: (str, optional). Defaults to empty string.
+            Model deployment url.
         kwargs:
-            Keyword arguments for initializing ModelDeploymentProperties
+            Keyword arguments for initializing `ModelDeploymentProperties`.
         """
 
         if config is None:
@@ -453,7 +452,7 @@ class ModelDeployment:
         return self.ds_client.list_work_request_logs(self.workflow_req_id).data
 
     def predict(
-        self, json_input: dict = None, data: Union[bytes, dict] = None, **kwargs
+        self, json_input: dict = None, data: InputDataSerializer = None, **kwargs
     ) -> dict:
         """Returns prediction of input data run against the model deployment endpoint
 
@@ -461,8 +460,8 @@ class ModelDeployment:
         ----------
         json_input: dict
             Json payload for the prediction.
-        data: Union[bytes, dict]
-            Payload for the prediction.
+        data: InputDataSerializer
+            Serialized Data  class instance
 
         kwargs:
             content_type: str
@@ -476,37 +475,26 @@ class ModelDeployment:
             Prediction results.
 
         """
-        endpoint = self.url
+        endpoint = f"{self.url}/predict"
         signer = self.config.get("signer")
-        if not data and not json_input:
+        if data is None and json_input is None:
             raise AttributeError(
                 "Neither `data` nor `json_input` are provided. You need to provide one of them."
             )
-        if data and json_input:
+        if data is not None and json_input is not None:
             raise AttributeError(
                 "`data` and `json_input` are both provided. You can only use one of them."
             )
+        if data is None:
+            data = InputDataSerializer(data=json_input)
+        elif not isinstance(data, InputDataSerializer):
+            data = InputDataSerializer(data=data)
 
-        content_type = kwargs.get("content_type", None)
-
-        if data:
-            if isinstance(data, dict):
-                response = requests.post(
-                    f"{endpoint}/predict", json=data, auth=signer
-                ).json()
-            else:
-                if not content_type:
-                    content_type = DEFAULT_CONTENT_TYPE_BYTES
-                headers = {"Content-Type": content_type}
-                response = requests.post(
-                    f"{endpoint}/predict", data=data, auth=signer, headers=headers
-                ).json()
-
-        else:
-            response = requests.post(
-                f"{endpoint}/predict", json=json_input, auth=signer
-            ).json()
-        return response
+        send_kwargs = {
+            "signer": signer,
+            "content_type": kwargs.get("content_type", None),
+        }
+        return data.send(endpoint=endpoint, **send_kwargs)
 
     def _wait_for_deletion(
         self,
