@@ -16,15 +16,16 @@ from ads.common.decorator.runtime_dependency import (
     runtime_dependency,
     OptionalDependency,
 )
-from ads.common.utils import _serialize_input_helper
-from ads.model.generic_model import GenericModel
+from ads.common.data_serializer import InputDataSerializer
+from ads.model.generic_model import (
+    GenericModel,
+    DEFAULT_ONNX_FORMAT_MODEL_FILE_NAME,
+    DEFAULT_JOBLIB_FORMAT_MODEL_FILE_NAME,
+    DEFAULT_TXT_FORMAT_MODEL_FILE_NAME,
+)
 from ads.model.model_properties import ModelProperties
 from joblib import dump
 
-DEFAULT_ONNX_FORMAT_MODEL_FILE_NAME = "model.onnx"
-DEFAULT_JOBLIB_FORMAT_MODEL_FILE_NAME = "model.joblib"
-DEFAULT_TXT_FORMAT_MODEL_FILE_NAME = "model.txt"
-
 
 class LightGBMModel(GenericModel):
     """LightGBMModel class for estimators from Lightgbm framework.
@@ -421,7 +422,7 @@ class LightGBMModel(GenericModel):
             )
         return auto_generated_initial_types
 
-    def _serialize_input(
+    def get_data_serializer(
         self,
         data: Union[
             Dict,
@@ -437,15 +438,13 @@ class LightGBMModel(GenericModel):
         Parameters
         ----------
         data: Union[Dict, str, list, numpy.ndarray, pd.core.series.Series,
-        pd.core.frame.DataFrame, torch.Tensor]
+        pd.core.frame.DataFrame]
             Data expected by the model deployment predict API.
-        data_type: Any, defaults to None.
-            Type of the data. If not provided, it will be checked against data.
 
         Returns
         -------
-        Dict
-            A dictionary containing serialized input data and original data type
+        InputDataSerializer
+            A class containing serialized input data and original data type
             information.
 
         Raises
@@ -453,12 +452,4 @@ class LightGBMModel(GenericModel):
         TypeError
             if provided data type is not supported.
         """
-        try:
-            return _serialize_input_helper(data)
-        except:
-            raise TypeError(
-                "The supported data types are Dict, str, list, "
-                "numpy.ndarray, pd.core.series.Series, "
-                "pd.core.frame.DataFrame. Please "
-                "convert to the supported data types first. "
-            )
+        return InputDataSerializer(data)
