@@ -5,23 +5,30 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import json
+import inspect
 import os
+import shutil
 import tempfile
 import yaml
-from enum import Enum, auto
+from enum import Enum
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 import cloudpickle
 import numpy as np
 import pandas as pd
 import requests
+import yaml
 from ads.catalog.model import ModelCatalog
+from ads.common import utils
 from ads.common import auth as authutil
 from ads.common import logger, oci_client
+from ads.common.data_serializer import InputDataSerializer
 from ads.common.decorator.runtime_dependency import (
     OptionalDependency,
     runtime_dependency,
 )
+from ads.common.decorator.utils import class_or_instance_method
+from ads.common.model_artifact import fetch_manifest_from_conda_location
 from ads.common.model_export_util import ONNXTransformer
 from ads.common.model_introspect import (
     TEST_STATUS,
@@ -49,8 +56,6 @@ from ads.feature_engineering.schema import Schema
 from ads.model.artifact import ModelArtifact
 from ads.model.common.utils import _extract_locals
 from ads.model.deployment import (
-    DEFAULT_CONTENT_TYPE_JSON,
-    DEFAULT_CONTENT_TYPE_BYTES,
     DEFAULT_POLL_INTERVAL,
     DEFAULT_WAIT_TIME,
     ModelDeployer,
@@ -61,8 +66,6 @@ from ads.model.deployment.common.utils import State as ModelDeploymentState
 from ads.model.model_properties import ModelProperties
 from ads.model.runtime.env_info import DEFAULT_CONDA_BUCKET_NAME
 from ads.model.runtime.runtime_info import RuntimeInfo
-from ads.common.model_artifact import fetch_manifest_from_conda_location
-
 
 _TRAINING_RESOURCE_ID = JOB_RUN_OCID or NB_SESSION_OCID
 _COMPARTMENT_OCID = NB_SESSION_COMPARTMENT_OCID or JOB_RUN_COMPARTMENT_OCID
@@ -71,6 +74,11 @@ MODEL_DEPLOYMENT_INSTANCE_SHAPE = "VM.Standard2.1"
 MODEL_DEPLOYMENT_INSTANCE_COUNT = 1
 MODEL_DEPLOYMENT_BANDWIDTH_MBPS = 10
 
+DEFAULT_ONNX_FORMAT_MODEL_FILE_NAME = "model.onnx"
+DEFAULT_JSON_FORMAT_MODEL_FILE_NAME = "model.json"
+DEFAULT_JOBLIB_FORMAT_MODEL_FILE_NAME = "model.joblib"
+DEFAULT_TXT_FORMAT_MODEL_FILE_NAME = "model.txt"
+DEFAULT_MODEL_FOLDER_NAME = "model"
 
 ONNX_DATA_TRANSFORMER = "onnx_data_transformer.json"
 _ATTRIBUTES_TO_SHOW_ = [
@@ -80,6 +88,11 @@ _ATTRIBUTES_TO_SHOW_ = [
     "model_id",
     "model_deployment_id",
 ]
+FRAMEWORKS_WITHOUT_ONNX_DATA_TRANSFORM = [
+    Framework.TENSORFLOW,
+    Framework.PYTORCH,
+    Framework.SPARK,
+]
 
 
 class NotActiveDeploymentError(Exception):
@@ -208,6 +221,8 @@ class GenericModel(MetadataMixin, Introspectable):
     >>> model.delete_deployment()
     """
 
+    _summary_status = None
+
     def __init__(
         self,
         estimator: Callable,
@@ -243,6 +258,7 @@ class GenericModel(MetadataMixin, Introspectable):
         self.metadata_provenance = ModelProvenanceMetadata()
         self.schema_input = Schema()
         self.schema_output = Schema()
+        self.data_serializer_class = InputDataSerializer
         self.model_file_name = None
         if artifact_dir:
             self.artifact_dir = os.path.abspath(os.path.expanduser(artifact_dir))
@@ -359,7 +375,7 @@ class GenericModel(MetadataMixin, Introspectable):
         force_overwrite: bool = False,
     ):
         """Apply onnx data transformer to data."""
-        if self.framework in [Framework.TENSORFLOW, Framework.PYTORCH] or X is None:
+        if self.framework in FRAMEWORKS_WITHOUT_ONNX_DATA_TRANSFORM or X is None:
             return X
         try:
             if hasattr(self, "onnx_data_preprocessor") and isinstance(
@@ -574,7 +590,13 @@ class GenericModel(MetadataMixin, Introspectable):
             jinja_template_filename = "score_onnx_new"
         else:
             if self.framework:
-                jinja_template_filename = "score_" + self.framework
+                if self.framework == "other":
+                    logger.warn(
+                        f"Framework: other given. Attempting to use the spark template for score.py generation."
+                    )
+                    jinja_template_filename = "score_spark"
+                else:
+                    jinja_template_filename = "score_" + self.framework
             else:
                 jinja_template_filename = (
                     "score-pkl" if self._serialize else "score_generic"
@@ -609,13 +631,17 @@ class GenericModel(MetadataMixin, Introspectable):
             status=ModelState.AVAILABLE.value,
         )
 
-    def verify(self, data: Any, **kwargs) -> Dict[str, Any]:
+    def verify(
+        self, data: Any, reload_artifacts: bool = True, **kwargs
+    ) -> Dict[str, Any]:
         """test if deployment works in local environment.
 
         Parameters
         ----------
-        data: Any.
+        data: Any
             Data used to test if deployment works in local environment.
+        reload_artifacts: bool. Defaults to True.
+            Whether to reload artifacts or not.
         kwargs:
             content_type: str, used to indicate the media type of the resource.
 
@@ -624,38 +650,17 @@ class GenericModel(MetadataMixin, Introspectable):
         Dict
             A dictionary which contains prediction results.
         """
-        url = f"http://127.0.0.1:8000/predict"
-        content_type = kwargs.get("content_type", None)
-        data_dict = self._handle_input_data(data)
-        if isinstance(data_dict, dict) and "bytes" in data_dict["data_type"]:
-            if not content_type:
-                content_type = DEFAULT_CONTENT_TYPE_BYTES
-            headers = {
-                "Content-Type": content_type,
-                "Accept": "*/*",
-            }
-            # should pass bytes when using data
-            req = requests.Request(
-                "POST", url, data=data_dict["data"], headers=headers
-            ).prepare()
-            request_body = req.body
-        else:
-            if not content_type:
-                content_type = DEFAULT_CONTENT_TYPE_JSON
-            headers = {
-                "Content-Type": content_type,
-                "Accept": "*/*",
-            }
-            req = requests.Request(
-                "POST", url, json=data_dict, headers=headers
-            ).prepare()
-            request_body = json.loads(req.body)
+        endpoint = f"http://127.0.0.1:8000/predict"
 
-        self.model_artifact.reload()
+        serialized_data = self.get_data_serializer(data)
+        request_body = serialized_data.send(endpoint, dry_run=True, **kwargs)
+
+        if reload_artifacts:
+            self.model_artifact.reload()
         prediction = self.model_artifact.predict(request_body)
 
         try:
-            req = requests.Request("POST", url, json=prediction, headers=headers)
+            requests.Request("POST", endpoint, json=prediction)
         except:
             raise TypeError(
                 "The prediction result is not json serializable. "
@@ -667,40 +672,6 @@ class GenericModel(MetadataMixin, Introspectable):
         )
         return prediction
 
-    def _serialize_input(
-        self,
-        data: Union[
-            Dict,
-            str,
-            List,
-            np.ndarray,
-            pd.core.series.Series,
-            pd.core.frame.DataFrame,
-        ],
-    ) -> Union[Dict, List, str]:
-        """Returns serializable input data.
-
-        Parameters
-        ----------
-        data: Union[Dict, str, list, numpy.ndarray,
-        pd.core.series.Series,  pd.core.frame.DataFrame]
-        data_type: (Any, otional). Defaults to None.
-            Type of the data. If not provided, it will be checked against data.
-
-        Returns
-        -------
-        Union[Dict, List, str]
-            Serializable input data.
-
-        Raises
-        ------
-        TypeError
-            If provided data type is not supported.
-        """
-        raise SerializeInputNotImplementedError(
-            "`_serialize_input` is not implemented."
-        )
-
     def introspect(self) -> pd.DataFrame:
         """Conducts instrospection.
 
@@ -779,7 +750,7 @@ class GenericModel(MetadataMixin, Introspectable):
         )
         model.model_file_name = model_file_name
         model.model_artifact = model_artifact
-        model.reload()
+        model.reload_runtime_info()
         model._summary_status.update_status(
             detail="Generated score.py", status=ModelState.DONE.value
         )
@@ -804,6 +775,8 @@ class GenericModel(MetadataMixin, Introspectable):
         auth: Optional[Dict] = None,
         force_overwrite: Optional[bool] = False,
         properties: Optional[Union[ModelProperties, Dict]] = None,
+        bucket_uri: Optional[str] = None,
+        remove_existing_artifact: Optional[bool] = True,
         **kwargs,
     ) -> "GenericModel":
         """Loads model from model catalog.
@@ -825,6 +798,12 @@ class GenericModel(MetadataMixin, Introspectable):
             Whether to overwrite existing files or not.
         properties: (ModelProperties, optional). Defaults to None.
             ModelProperties object required to save and deploy model.
+        bucket_uri: (str, optional). Defaults to None.
+            The OCI Object Storage URI where model artifacts will be copied to.
+            The `bucket_uri` is only necessary for downloading large artifacts with
+            size is greater than 2GB. Example: `oci://<bucket_name>@<namespace>/prefix/`.
+        remove_existing_artifact: (bool, optional). Defaults to `True`.
+            Wether artifacts uploaded to object storage bucket need to be removed or not.
         kwargs:
             compartment_id : (str, optional)
                 Compartment OCID. If not specified, the value will be taken from the environment variables.
@@ -851,9 +830,14 @@ class GenericModel(MetadataMixin, Introspectable):
             timeout=kwargs.pop("timeout", None),
         )
 
-        model_catalog._download_artifacts(model_id, artifact_dir, force_overwrite)
+        model_catalog._download_artifact(
+            model_id=model_id,
+            target_dir=artifact_dir,
+            force_overwrite=force_overwrite,
+            bucket_uri=bucket_uri,
+            remove_existing_artifact=remove_existing_artifact,
+        )
         oci_model = model_catalog.get_model(model_id)
-
         result_model = cls.from_model_artifact(
             uri=artifact_dir,
             model_file_name=model_file_name,
@@ -863,6 +847,7 @@ class GenericModel(MetadataMixin, Introspectable):
             properties=properties,
         )
 
+        result_model.model_id = model_id
         # Populate metadata
         result_model.metadata_custom = oci_model.metadata_custom
         result_model.metadata_taxonomy = oci_model.metadata_taxonomy
@@ -898,6 +883,8 @@ class GenericModel(MetadataMixin, Introspectable):
         auth: Optional[Dict] = None,
         force_overwrite: Optional[bool] = False,
         properties: Optional[Union[ModelProperties, Dict]] = None,
+        bucket_uri: Optional[str] = None,
+        remove_existing_artifact: Optional[bool] = True,
         **kwargs,
     ) -> "GenericModel":
         """Loads model from model deployment.
@@ -919,6 +906,12 @@ class GenericModel(MetadataMixin, Introspectable):
             Whether to overwrite existing files or not.
         properties: (ModelProperties, optional). Defaults to None.
             ModelProperties object required to save and deploy model.
+        bucket_uri: (str, optional). Defaults to None.
+            The OCI Object Storage URI where model artifacts will be copied to.
+            The `bucket_uri` is only necessary for downloading large artifacts with
+            size is greater than 2GB. Example: `oci://<bucket_name>@<namespace>/prefix/`.
+        remove_existing_artifact: (bool, optional). Defaults to `True`.
+            Wether artifacts uploaded to object storage bucket need to be removed or not.
         kwargs:
             compartment_id : (str, optional)
                 Compartment OCID. If not specified, the value will be taken from the environment variables.
@@ -945,6 +938,8 @@ class GenericModel(MetadataMixin, Introspectable):
             auth=auth,
             force_overwrite=force_overwrite,
             properties=properties,
+            bucket_uri=bucket_uri,
+            remove_existing_artifact=remove_existing_artifact,
             **kwargs,
         )
         model._summary_status.update_status(
@@ -959,6 +954,23 @@ class GenericModel(MetadataMixin, Introspectable):
         )
         return model
 
+    def reload_runtime_info(self) -> None:
+        """Reloads the model artifact file: `runtime.yaml`.
+
+        Returns
+        -------
+        None
+            Nothing.
+        """
+        # reload runtime.yaml
+        runtime_yaml_file = os.path.join(self.artifact_dir, "runtime.yaml")
+        if not os.path.exists(runtime_yaml_file):
+            raise FileNotFoundError(
+                f"`runtime.yaml` does not exist in {self.artifact_dir}. "
+                "Use `RuntimeInfo` class to populate it."
+            )
+        self.runtime_info = RuntimeInfo.from_yaml(uri=runtime_yaml_file)
+
     def reload(self) -> None:
         """Reloads the model artifact files: `score.py` and the `runtime.yaml`.
 
@@ -969,17 +981,9 @@ class GenericModel(MetadataMixin, Introspectable):
         """
         # reload the score.py
         self.model_artifact.reload()
-
         # reload runtime.yaml
-        runtime_yaml_file = os.path.join(self.artifact_dir, "runtime.yaml")
-        if not os.path.exists(runtime_yaml_file):
-            raise FileNotFoundError(
-                f"`runtime.yaml` does not exist in {self.artifact_dir}. "
-                "Use `RuntimeInfo` class to populate it."
-            )
-        self.runtime_info = RuntimeInfo.from_yaml(uri=runtime_yaml_file)
+        self.reload_runtime_info()
 
-    @runtime_dependency(module="IPython", install_from=OptionalDependency.NOTEBOOK)
     def save(
         self,
         display_name: Optional[str] = None,
@@ -987,14 +991,19 @@ class GenericModel(MetadataMixin, Introspectable):
         freeform_tags: Optional[dict] = None,
         defined_tags: Optional[dict] = None,
         ignore_introspection: Optional[bool] = False,
+        bucket_uri: Optional[str] = None,
+        overwrite_existing_artifact: Optional[bool] = True,
+        remove_existing_artifact: Optional[bool] = True,
         **kwargs,
-    ) -> None:
+    ) -> str:
         """Saves model artifacts to the model catalog.
 
         Parameters
         ----------
         display_name: (str, optional). Defaults to None.
-            The name of the model.
+            The name of the model. If a display_name is not provided in kwargs,
+            randomly generated easy to remember name with timestamp will be generated,
+            like 'strange-spider-2022-08-17-23:55.02'.
         description: (str, optional). Defaults to None.
             The description of the model.
         freeform_tags : Dict(str, str), Defaults to None.
@@ -1004,6 +1013,14 @@ class GenericModel(MetadataMixin, Introspectable):
         ignore_introspection: (bool, optional). Defaults to None.
             Determine whether to ignore the result of model introspection or not.
             If set to True, the save will ignore all model introspection errors.
+        bucket_uri: (str, optional). Defaults to None.
+            The OCI Object Storage URI where model artifacts will be copied to.
+            The `bucket_uri` is only necessary for uploading large artifacts which
+            size is greater than 2GB. Example: `oci://<bucket_name>@<namespace>/prefix/`.
+        overwrite_existing_artifact: (bool, optional). Defaults to `True`.
+            Overwrite target bucket artifact if exists.
+        remove_existing_artifact: (bool, optional). Defaults to `True`.
+            Wether artifacts uploaded to object storage bucket need to be removed or not.
         kwargs:
             project_id: (str, optional).
                 Project OCID. If not specified, the value will be taken either
@@ -1013,6 +1030,7 @@ class GenericModel(MetadataMixin, Introspectable):
                 from the environment variables or model properties.
             timeout: (int, optional). Defaults to 10 seconds.
                 The connection timeout in seconds for the client.
+
         Raises
         ------
         RuntimeInfoInconsistencyError
@@ -1023,6 +1041,9 @@ class GenericModel(MetadataMixin, Introspectable):
         str
             model id.
         """
+        # Set default display_name if not specified - randomly generated easy to remember name generated
+        if not display_name:
+            display_name = utils.get_random_name_for_resource()
         # populates properties from args and kwargs. Empty values will be ignored.
         self.properties.with_dict(_extract_locals(locals()))
         self.properties.compartment_id = (
@@ -1048,26 +1069,18 @@ class GenericModel(MetadataMixin, Introspectable):
             if self._introspect.status == TEST_STATUS.NOT_PASSED:
                 msg = (
                     "Model introspection not passed. "
-                    "See the table below for "
-                    "more detailed information and follow the messages to fix it, "
-                    "otherwise you might come across errors during model deployment. "
-                    "To save model artifacts ignoring "
-                    "introspection use .save(ignore_introspection=True...)."
+                    "Use `.introspect()` method to get detailed information and follow the "
+                    "messages to fix it. To save model artifacts ignoring introspection "
+                    "use `.save(ignore_introspection=True...)`."
                 )
-                logger.error(msg)
-
-                from IPython.core.display import display
-
-                display(self._introspect.to_dataframe())
-
                 self._summary_status.update_status(
                     detail="Conducted Introspect Test", status="Failed"
                 )
                 self._summary_status.update_action(
                     detail="Conducted Introspect Test",
-                    action=f"Check introspect table for the reason why it failed.",
+                    action=f"Use `.introspect()` method to get detailed information.",
                 )
-                raise IntrospectionNotPassed()
+                raise IntrospectionNotPassed(msg)
             else:
                 self._summary_status.update_status(
                     detail="Conducted Introspect Test", status=ModelState.DONE.value
@@ -1091,6 +1104,9 @@ class GenericModel(MetadataMixin, Introspectable):
             description=description,
             freeform_tags=freeform_tags,
             defined_tags=defined_tags,
+            bucket_uri=bucket_uri,
+            remove_existing_artifact=remove_existing_artifact,
+            overwrite_existing_artifact=overwrite_existing_artifact,
         )
         self.model_id = oci_model.id
 
@@ -1125,6 +1141,8 @@ class GenericModel(MetadataMixin, Introspectable):
         deployment_log_group_id: Optional[str] = None,
         deployment_access_log_id: Optional[str] = None,
         deployment_predict_log_id: Optional[str] = None,
+        deployment_memory_in_gbs: Optional[float] = None,
+        deployment_ocpus: Optional[float] = None,
         **kwargs: Dict,
     ) -> ModelDeployment:
         """
@@ -1135,7 +1153,9 @@ class GenericModel(MetadataMixin, Introspectable):
         wait_for_completion : (bool, optional). Defaults to True.
             Flag set for whether to wait for deployment to complete before proceeding.
         display_name: (str, optional). Defaults to None.
-            The name of the model.
+            The name of the model. If a display_name is not provided in kwargs,
+            a randomly generated easy to remember name with timestamp will be generated,
+            like 'strange-spider-2022-08-17-23:55.02'.
         description: (str, optional). Defaults to None.
             The description of the model.
         deployment_instance_shape: (str, optional). Default to `VM.Standard2.1`.
@@ -1144,6 +1164,10 @@ class GenericModel(MetadataMixin, Introspectable):
             The number of instance used for deployment.
         deployment_bandwidth_mbps: (int, optional). Defaults to 10.
             The bandwidth limit on the load balancer in Mbps.
+        deployment_memory_in_gbs: (float, optional). Defaults to None.
+            Specifies the size of the memory of the model deployment instance in GBs.
+        deployment_ocpus: (float, optional). Defaults to None.
+            Specifies the ocpus count of the model deployment instance.
         deployment_log_group_id: (str, optional). Defaults to None.
             The oci logging group id. The access log and predict log share the same log group.
         deployment_access_log_id: (str, optional). Defaults to None.
@@ -1160,6 +1184,13 @@ class GenericModel(MetadataMixin, Introspectable):
                 Negative implies infinite wait time.
             poll_interval : (int, optional). Defaults to 60 seconds.
                 Poll interval in seconds.
+            freeform_tags: (Dict[str, str], optional). Defaults to None.
+                Freeform tags of the model deployment.
+            defined_tags: (Dict[str, dict[str, object]], optional). Defaults to None.
+                Defined tags of the model deployment.
+
+            Also can be any keyword argument for initializing the `ads.model.deployment.ModelDeploymentProperties`.
+            See `ads.model.deployment.ModelDeploymentProperties()` for details.
 
         Returns
         -------
@@ -1171,6 +1202,9 @@ class GenericModel(MetadataMixin, Introspectable):
         ValueError
             If `model_id` is not specified.
         """
+        # Set default display_name if not specified - randomly generated easy to remember name generated
+        if not display_name:
+            display_name = utils.get_random_name_for_resource()
         # populates properties from args and kwargs. Empty values will be ignored.
         self.properties.with_dict(_extract_locals(locals()))
         # clears out project_id and compartment_id from kwargs, to prevent passing
@@ -1178,6 +1212,9 @@ class GenericModel(MetadataMixin, Introspectable):
         kwargs.pop("project_id", None)
         kwargs.pop("compartment_id", None)
 
+        max_wait_time = kwargs.pop("max_wait_time", DEFAULT_WAIT_TIME)
+        poll_interval = kwargs.pop("poll_interval", DEFAULT_POLL_INTERVAL)
+
         self.properties.compartment_id = (
             self.properties.compartment_id or _COMPARTMENT_OCID
         )
@@ -1211,7 +1248,7 @@ class GenericModel(MetadataMixin, Introspectable):
             )
 
         model_deployment_properties = (
-            ModelDeploymentProperties(self.model_id, config=self.auth)
+            ModelDeploymentProperties(self.model_id, config=self.auth, **kwargs)
             .with_prop("display_name", display_name)
             .with_prop("description", description)
             .with_prop("project_id", self.properties.project_id)
@@ -1221,6 +1258,8 @@ class GenericModel(MetadataMixin, Introspectable):
                     "INSTANCE_SHAPE": self.properties.deployment_instance_shape,
                     "INSTANCE_COUNT": self.properties.deployment_instance_count,
                     "bandwidth_mbps": self.properties.deployment_bandwidth_mbps,
+                    "memory_in_gbs": self.properties.deployment_memory_in_gbs,
+                    "ocpus": self.properties.deployment_ocpus,
                 }
             )
         )
@@ -1242,8 +1281,8 @@ class GenericModel(MetadataMixin, Introspectable):
         self.model_deployment = ModelDeployer(config=self.auth).deploy(
             properties=model_deployment_properties,
             wait_for_completion=wait_for_completion,
-            max_wait_time=kwargs.pop("max_wait_time", DEFAULT_WAIT_TIME),
-            poll_interval=kwargs.pop("poll_interval", DEFAULT_POLL_INTERVAL),
+            max_wait_time=max_wait_time,
+            poll_interval=poll_interval,
             **kwargs,
         )
         self._summary_status.update_status(
@@ -1284,8 +1323,13 @@ class GenericModel(MetadataMixin, Introspectable):
         deployment_log_group_id: Optional[str] = None,
         deployment_access_log_id: Optional[str] = None,
         deployment_predict_log_id: Optional[str] = None,
+        deployment_memory_in_gbs: Optional[float] = None,
+        deployment_ocpus: Optional[float] = None,
+        bucket_uri: Optional[str] = None,
+        overwrite_existing_artifact: Optional[bool] = True,
+        remove_existing_artifact: Optional[bool] = True,
         **kwargs: Dict,
-    ):
+    ) -> ModelDeployment:
         """Shortcut for prepare, save and deploy steps.
 
         Parameters
@@ -1334,7 +1378,9 @@ class GenericModel(MetadataMixin, Introspectable):
             Do not generate the input schema if the input has more than this
             number of features(columns).
         model_display_name: (str, optional). Defaults to None.
-            The name of the model.
+            The name of the model. If a model_display_name is not provided in kwargs,
+            a randomly generated easy to remember name with timestamp will be generated,
+            like 'strange-spider-2022-08-17-23:55.02'.
         model_description: (str, optional). Defaults to None.
             The description of the model.
         model_freeform_tags : Dict(str, str), Defaults to None.
@@ -1346,8 +1392,10 @@ class GenericModel(MetadataMixin, Introspectable):
             If set to True, the save will ignore all model introspection errors.
         wait_for_completion : (bool, optional). Defaults to True.
             Flag set for whether to wait for deployment to complete before proceeding.
-        display_name: (str, optional). Defaults to None.
-            The name of the model.
+        deployment_display_name: (str, optional). Defaults to None.
+            The name of the model deployment. If a deployment_display_name is not provided in kwargs,
+            a randomly generated easy to remember name with timestamp will be generated,
+            like 'strange-spider-2022-08-17-23:55.02'.
         description: (str, optional). Defaults to None.
             The description of the model.
         deployment_instance_shape: (str, optional). Default to `VM.Standard2.1`.
@@ -1362,6 +1410,18 @@ class GenericModel(MetadataMixin, Introspectable):
             The access log OCID for the access logs. https://docs.oracle.com/en-us/iaas/data-science/using/model_dep_using_logging.htm
         deployment_predict_log_id: (str, optional). Defaults to None.
             The predict log OCID for the predict logs. https://docs.oracle.com/en-us/iaas/data-science/using/model_dep_using_logging.htm
+        deployment_memory_in_gbs: (float, optional). Defaults to None.
+            Specifies the size of the memory of the model deployment instance in GBs.
+        deployment_ocpus: (float, optional). Defaults to None.
+            Specifies the ocpus count of the model deployment instance.
+        bucket_uri: (str, optional). Defaults to None.
+            The OCI Object Storage URI where model artifacts will be copied to.
+            The `bucket_uri` is only necessary for downloading large artifacts with
+            size is greater than 2GB. Example: `oci://<bucket_name>@<namespace>/prefix/`.
+        overwrite_existing_artifact: (bool, optional). Defaults to `True`.
+            Overwrite target bucket artifact if exists.
+        remove_existing_artifact: (bool, optional). Defaults to `True`.
+            Wether artifacts uploaded to object storage bucket need to be removed or not.
         kwargs:
             impute_values: (dict, optional).
                 The dictionary where the key is the column index(or names is accepted
@@ -1379,6 +1439,13 @@ class GenericModel(MetadataMixin, Introspectable):
                 Negative implies infinite wait time.
             poll_interval : (int, optional). Defaults to 60 seconds.
                 Poll interval in seconds.
+            freeform_tags: (Dict[str, str], optional). Defaults to None.
+                Freeform tags of the model deployment.
+            defined_tags: (Dict[str, dict[str, object]], optional). Defaults to None.
+                Defined tags of the model deployment.
+
+            Also can be any keyword argument for initializing the `ads.model.deployment.ModelDeploymentProperties`.
+            See `ads.model.deployment.ModelDeploymentProperties()` for details.
 
         Returns
         -------
@@ -1413,6 +1480,10 @@ class GenericModel(MetadataMixin, Introspectable):
             max_col_num=max_col_num,
             impute_values=kwargs.pop("impute_values", None),
         )
+        # Set default model_display_name if not specified - randomly generated easy to remember name generated
+        if not model_display_name:
+            model_display_name = utils.get_random_name_for_resource()
+
         self.save(
             display_name=model_display_name,
             description=model_description,
@@ -1422,7 +1493,14 @@ class GenericModel(MetadataMixin, Introspectable):
             compartment_id=self.properties.compartment_id,
             project_id=self.properties.project_id,
             timeout=kwargs.pop("timeout", None),
+            bucket_uri=bucket_uri,
+            overwrite_existing_artifact=overwrite_existing_artifact,
+            remove_existing_artifact=remove_existing_artifact,
         )
+        # Set default deployment_display_name if not specified - randomly generated easy to remember name generated
+        if not deployment_display_name:
+            deployment_display_name = utils.get_random_name_for_resource()
+
         self.deploy(
             wait_for_completion=wait_for_completion,
             display_name=deployment_display_name,
@@ -1433,6 +1511,8 @@ class GenericModel(MetadataMixin, Introspectable):
             deployment_log_group_id=self.properties.deployment_log_group_id,
             deployment_access_log_id=self.properties.deployment_access_log_id,
             deployment_predict_log_id=self.properties.deployment_predict_log_id,
+            deployment_memory_in_gbs=self.properties.deployment_memory_in_gbs,
+            deployment_ocpus=self.properties.deployment_ocpus,
             kwargs=kwargs,
         )
         return self.model_deployment
@@ -1470,23 +1550,20 @@ class GenericModel(MetadataMixin, Introspectable):
         current_state = self.model_deployment.state.name.upper()
         if current_state != ModelDeploymentState.ACTIVE.name:
             raise NotActiveDeploymentError(current_state)
-        data_dict = self._handle_input_data(data)
 
-        if isinstance(data_dict, dict) and "bytes" in data_dict["data_type"]:
-            prediction = self.model_deployment.predict(data=data_dict["data"], **kwargs)
-        else:
-            prediction = self.model_deployment.predict(json_input=data_dict, **kwargs)
+        serialized_data = self.get_data_serializer(data)
+        prediction = self.model_deployment.predict(data=serialized_data, **kwargs)
 
         self._summary_status.update_status(
             detail="Called deployment predict endpoint", status=ModelState.DONE.value
         )
         return prediction
 
-    def _handle_input_data(self, data: any):
-        """For generic model where _serialize_input is not implemented, check
-        if the data is json serializable. For other frameworks, serialize the
-        data using _serialize_input and double check if the resulted data is
-        json serializable.
+    def get_data_serializer(self, data: any):
+        """The data_serializer_class class is set in ``init`` and used here.
+        Frameworks should subclass the InputDataSerializer class, then
+        set that as the ``self.data_serializer_class``.
+        Frameworks should avoid overwriting this method whenever possible.
 
         Parameters
         ----------
@@ -1498,17 +1575,7 @@ class GenericModel(MetadataMixin, Introspectable):
         data
             Serialized data.
         """
-        try:
-            data_dict = self._serialize_input(data)
-        except SerializeInputNotImplementedError as e:
-            data_dict = data
-            if isinstance(data, bytes):
-                data_dict = {
-                    "data": data,
-                    "data_type": str(type(data)),
-                }
-
-        return data_dict
+        return self.data_serializer_class(data=data)
 
     @staticmethod
     def _is_json_serializable(data: Any) -> bool:
@@ -1613,27 +1680,75 @@ class GenericModel(MetadataMixin, Introspectable):
             raise ValueError("Use `deploy()` method to start model deployment.")
         self.model_deployment.delete(wait_for_completion=wait_for_completion)
 
-    def _delete_model(self, model_id: str = None):
-        """Deletes the remote model artifact on the model catalog.
+    @class_or_instance_method
+    def delete(
+        cls,
+        model_id: Optional[str] = None,
+        delete_associated_model_deployment: Optional[bool] = False,
+        delete_model_artifact: Optional[bool] = False,
+        artifact_dir: Optional[str] = None,
+        **kwargs: Dict,
+    ) -> None:
+        """
+        Deletes a model from Model Catalog.
 
         Parameters
         ----------
-        model_id: (str, optional). Defaults to current saved model artfact id.
-            model artifact id to be deleted.
+        model_id: (str, optional). Defaults to None.
+            The model OCID to be deleted.
+            If the method called on instance level, then `self.model_id` will be used.
+        delete_associated_model_deployment: (bool, optional). Defaults to `False`.
+            Whether associated model deployments need to be deleted or not.
+        delete_model_artifact: (bool, optional). Defaults to `False`.
+            Whether associated model artifacts need to be deleted or not.
+        artifact_dir: (str, optional). Defaults to `None`
+            The local path to the model artifacts folder.
+            If the method called on instance level,
+            the `self.artifact_dir` will be used by default.
+        kwargs:
+            auth: (Dict, optional). Defaults to `None`.
+                The default authetication is set using `ads.set_auth` API.
+                If you need to override the default, use the `ads.common.auth.api_keys` or
+                `ads.common.auth.resource_principal` to create appropriate authentication signer
+                and kwargs required to instantiate IdentityClient object.
+            compartment_id: (str, optional). Defaults to `None`.
+                Compartment OCID.
+                If not specified, the value will be taken from the environment variables.
+            timeout: (int, optional). Defaults to 10 seconds.
+                The connection timeout in seconds for the client.
+        Returns
+        -------
+        None
 
         Raises
         ------
-        ValueError: if model id cannot be found.
+        ValueError
+            If `model_id` not provided.
         """
-        if model_id:
-            model_id = model_id
-        elif hasattr(self, "model_id"):
-            model_id = self.model_id
-        else:
-            raise ValueError(
-                "Cannot find model to delete. `model_id` needs to be provided."
-            )
-        self.model_catalog.delete_model(model=model_id)
+        if not inspect.isclass(cls):
+            model_id = model_id or cls.model_id
+            artifact_dir = artifact_dir or cls.artifact_dir
+
+        if not model_id:
+            raise ValueError("The `model_id` must be provided.")
+        if delete_model_artifact and not artifact_dir:
+            raise ValueError("The `artifact_dir` must be provided.")
+
+        auth = kwargs.pop("auth", None) or authutil.default_signer()
+        compartment_id = kwargs.pop("compartment_id", None) or _COMPARTMENT_OCID
+
+        ModelCatalog(
+            compartment_id=compartment_id,
+            ds_client_auth=auth,
+            identity_client_auth=auth,
+            timeout=kwargs.pop("timeout", None),
+        ).delete_model(
+            model=model_id,
+            delete_associated_model_deployment=delete_associated_model_deployment,
+        )
+
+        if delete_model_artifact:
+            shutil.rmtree(artifact_dir, ignore_errors=True)
 
 
 class ModelState(Enum):
@@ -1698,10 +1813,7 @@ class SummaryStatus:
         None
             Nothing.
         """
-        self.df.loc[
-            self.df["Details"] == detail,
-            "Status",
-        ] = status
+        self.df.loc[self.df["Details"] == detail, "Status"] = status
 
     def update_action(self, detail: str, action: str) -> None:
         """Updates the action of the summary status table of the corresponding detail.
