@@ -16,10 +16,7 @@ from distutils import dir_util
 from subprocess import Popen, PIPE, STDOUT
 from typing import Union, List, Tuple, Dict
 import shlex
-
-import docker
 import yaml
-from docker import errors
 
 import ads
 from ads.common.oci_client import OCIClientFactory
@@ -30,6 +27,10 @@ from ads.opctl.constants import (
     ML_JOB_GPU_IMAGE,
     OPS_IMAGE_GPU_BASE,
 )
+from ads.common.decorator.runtime_dependency import (
+    runtime_dependency,
+    OptionalDependency,
+)
 
 
 def get_service_pack_prefix() -> Dict:
@@ -168,6 +169,12 @@ def build_image(
         ]
         if target:
             command += ["--target", target]
+        if os.environ.get("no_proxy"):
+            command += ["--build-arg", f"no_proxy={os.environ['no_proxy']}"]
+        if os.environ.get("http_proxy"):
+            command += ["--build-arg", f"http_proxy={os.environ['http_proxy']}"]
+        if os.environ.get("https_proxy"):
+            command += ["--build-arg", f"https_proxy={os.environ['https_proxy']}"]
         command += [os.path.abspath(curr_dir)]
         logger.info(f"Build image with command {command}")
         proc = run_command(command)
@@ -185,6 +192,7 @@ def _get_image_name_dockerfile_target(type: str, gpu: bool) -> str:
     return look_up[(type, gpu)]
 
 
+@runtime_dependency(module="docker", install_from=OptionalDependency.OPCTL)
 def _build_custom_operator_image(
     gpu: bool, source_folder: str, dst_image: str
 ) -> None:  # pragma: no cover
@@ -193,7 +201,7 @@ def _build_custom_operator_image(
     try:
         client = docker.from_env()
         client.api.inspect_image(base_image_name)
-    except errors.ImageNotFound:
+    except docker.errors.ImageNotFound:
         build_image("ads-ops-base", gpu)
     with tempfile.TemporaryDirectory() as td:
         dir_util.copy_tree(source_folder, os.path.join(td, operator))
@@ -275,7 +283,8 @@ def suppress_traceback(debug: bool = True) -> None:
     return decorator
 
 
-def get_docker_client() -> docker.client.DockerClient:
+@runtime_dependency(module="docker", install_from=OptionalDependency.OPCTL)
+def get_docker_client() -> "docker.client.DockerClient":
     process = subprocess.Popen(
         ["docker", "info"], stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT
     )
@@ -307,6 +316,7 @@ class OCIAuthContext:
             ads.set_auth(auth="api_key", profile=self.prev_profile)
 
 
+@runtime_dependency(module="docker", install_from=OptionalDependency.OPCTL)
 def run_container(
     image: str,
     bind_volumes: Dict,
@@ -315,12 +325,20 @@ def run_container(
     entrypoint: str = None,
     verbose: bool = True,
 ):
+    print("All ready to create a docker image. Recap:\n")
+    print(f"image: {image}")
+    print(f"bind_volumes: {bind_volumes}")
+    print(f"env_vars: {env_vars}")
+    print(f"command: {command}")
+    print(f"entrypoint: {entrypoint}")
+
     client = get_docker_client()
     try:
         client.api.inspect_image(image)
-    except errors.ImageNotFound:
+    except docker.errors.ImageNotFound:
         logger.info(f"Image {image} not found. Try pulling it now....")
         run_command(["docker", "pull", f"{image}"], None)
+    print("Now running container")
     container = client.containers.run(
         image=image,
         volumes=bind_volumes,
@@ -331,11 +349,13 @@ def run_container(
         user=0,
         # auto_remove=True,
     )
+    print("Return from container")
     # auto_remove sometimes throws errors such as
     # docker.errors.NotFound: 404 Client Error for
     # http+docker://localhost/v1.41/containers/37b32d02b8ebccfb081952798123db714ccf8648bf0d00c1baa68ae3badaaf58/json:
     # Not Found ("No such container: 37b32d02b8ebccfb081952798123db714ccf8648bf0d00c1baa68ae3badaaf58")
-    if verbose:
-        for line in container.logs(stream=True):
-            print(line.decode("utf-8").strip())
-    container.remove()
+
+    # if verbose:
+    #     for line in container.logs(stream=True):
+    #         print(line.decode("utf-8").strip())
+    # container.remove()
